# FOAAP

*[FOAAS API v2.3.1](https://foaas.com/) compliant.*


[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![codecov](https://codecov.io/gh/ilhomidin/foaap/branch/main/graph/badge.svg?token=O0OYHO9VRT)](https://codecov.io/gh/ilhomidin/foaap)

FOAAP (Fuck Of As A Package) solves a simple [foaas-python](https://github.com/dmpayton/foaas-python) problem — telling people to fuck off, faster.

```python
import foaap


# Maybe. Maybe not. Maybe fuck yourself. - Syu
foaap.maybe("Syu")
```


# Installation
```bash
pip install foaap
```

# Supported Operations

- `absolutely(company: str, from_name: str)`
- `anyway(company: str, from_name: str)`
- `ashole(from_name: str)`
- `awesome(from_name: str)`
- `bag(from_name: str)`
- `balmer(name: str, company: str, from_name: str)`
- `back(name: str, from_name: str)`
- `bday(name: str, from_name: str)`
- `because(from_name: str)`
- `blackadder(name: str, from_name: str)`
- `bm(name: str, from_name: str)`
- `bucket(from_name: str)`
- `bus(name: str, from_name: str)`
- `bye(from_name: str)`
- `caniuse(tool: str, from_name: str)`
- `chainsaw(name: str, from_name: str)`
- `cocksplat(name: str, from_name: str)`
- `cool(from_name: str)`
- `cup(from_name: str)`
- `dalton(name: str, from_name: str)`
- `dense(from_name: str)`
- `deraadt(name: str, from_name: str)`
- `diabetes(from_name: str)`
- `donut(name: str, from_name: str)`
- `dosomething(do: str, something: str, from_name: str)`
- `dumbledore(from_name: str)`
- `equity(name: str, from_name: str)`
- `even(from_name: str)`
- `everyone(from_name: str)`
- `everything(from_name: str)`
- `family(from_name: str)`
- `fascinating(from_name: str)`
- `fewer(name: str, from_name: str)`
- `field(name: str, from_name: str, reference: str)`
- `flying(from_name: str)`
- `ftfy(from_name: str)`
- `fts(name: str, from_name: str)`
- `fyyff(from_name: str)`
- `gfy(name: str, from_name: str)`
- `give(from_name: str)`
- `greed(noun: str, from_name: str)`
- `holygrail(from_name: str)`
- `horse(from_name: str)`
- `idea(from_name: str)`
- `immensity(from_name: str)`
- `ing(name: str, from_name: str)`
- `jinglebells(from_name: str)`
- `keep(name: str, from_name: str)`
- `keepcalm(reaction: str, from_name: str)`
- `king(name: str, from_name: str)`
- `legend(name: str, from_name: str)`
- `life(from_name: str)`
- `linus(name: str, from_name: str)`
- `logs(from_name: str)`
- `look(name: str, from_name: str)`
- `looking(from_name: str)`
- `lowpoly(from_name: str)`
- `madison(name: str, from_name: str)`
- `maybe(from_name: str)`
- `me(from_name: str)`
- `mornin(from_name: str)`
- `no(from_name: str)`
- `nugget(name: str, from_name: str)`
- `off(name: str, from_name: str)`
- `off_with(behavior: str, from_name: str)`
- `outside(name: str, from_name: str)`
- `particular(thing: str, from_name: str)`
- `pink(from_name: str)`
- `problem(name: str, from_name: str)`
- `programmer(from_name: str)`
- `pulp(language: str, from_name: str)`
- `question(from_name: str)`
- `ratsarse(from_name: str)`
- `retard(from_name: str)`
- `ridiculous(from_name: str)`
- `rockstar(name: str, from_name: str)`
- `rtfm(from_name: str)`
- `sake(from_name: str)`
- `shakespeare(name: str, from_name: str)`
- `shit(from_name: str)`
- `shutup(name: str, from_name: str)`
- `single(from_name: str)`
- `thanks(from_name: str)`
- `that(from_name: str)`
- `think(name: str, from_name: str)`
- `thinking(name: str, from_name: str)`
- `this(from_name: str)`
- `thumbs(name: str, from_name: str)`
- `too(from_name: str)`
- `tucker(from_name: str)`
- `understand(name: str, from_name: str)`
- `waste(name: str, from_name: str)`
- `what(from_name: str)`
- `xmas(name: str, from_name: str)`
- `yeah(from_name: str)`
- `yoda(name: str, from_name: str)`
- `you(name: str, from_name: str)`
- `zayn(from_name: str)`
- `zero(from_name: str)`

